=========
squery-pg
=========

Library for managing PostgreSQL connections and schema migrations, with an easy
object-oriented API.

License
=======

This library is released under GPLv3. Please see the ``COPYING`` file in the
source tree.
